Learn R Programming

distillery (version 1.0-2)

distillery-package: distillery: Methods to Distill Information from R Objects

Description

distillery contains primarily method functions to distill out pertinent information from R objects, as well as to compute confidence intervals.

Arguments

Details

Primary functions include:

distill: Typically, to distill pertinent information from a complicated (usually a list) object and return a named vector.

ci: Calculate confidence intervals. This is a method function for calculating confidence intervals. Includes methods for numeric vectors and matrices, whereby the mean is taken (column-wise for matrices) and normal approximation confidence intervals for the mean are calculated and returned.

Examples

Run this code
## See help files for above named functions and datasets
## for specific examples.

Run the code above in your browser using DataLab