Learn R Programming

distillery (version 1.0-2)

is.formula: Is the R Object a Formula

Description

Tests to see if an object is a formula or not.

Usage

is.formula(x)

Arguments

x

An R object.

Value

single logical

Details

This is a very simple function that simplifies checking that the class of an object is a formula or not.

Examples

Run this code
is.formula(~1)
is.formula(1:3)

Run the code above in your browser using DataLab