Primary functions include:
distill: Typically, to distill pertinent information from a complicated (usually a list) object and return a named vector.
ci: Calculate confidence intervals. This is a method function for calculating confidence intervals. Includes methods for numeric vectors and matrices, whereby the mean is taken (column-wise for matrices) and normal approximation confidence intervals for the mean are calculated and returned.