powered by
Tests to see if an object is a formula or not.
is.formula(x)
An R object.
single logical
This is a very simple function that simplifies checking that the class of an object is a formula or not.
is.formula(~1) is.formula(1:3)
Run the code above in your browser using DataLab